Modules
Structs
- Service
Start Config - Create a new instance of the
ServiceStartConfigstruct using the builder. - Service
Start Config Builder - Use builder syntax to set the inputs and finish with
build(). - Service
Util - Wait
Strategy Error
Enums
- Service
Util Error - Wait
Strategy - Represents the strategy to wait for a container to reach a certain state.
Functions
- wait_
until_ console_ output - Waits until the console output of the container with the given ID contains the specified expected output. If the expected output is not found within the given timeout, an error is returned.
- wait_
until_ grpc_ health_ check - Waits until a gRPC service at the given
health_urlis online by performing a health check. The health check is performed every 100ms until the service responds or the giventimeoutis reached. If the timeout is reached without a response, aServiceUtilErroris returned. - wait_
until_ http_ health_ check - Waits until the health check URL responds successfully.
- wait_
until_ timeout - Waits for the given duration asynchronously.